@@ -3,8 +3,7 @@
 #ifndef OUTPUTDIRECTORY_H
 #define OUTPUTDIRECTORY_H
 
-#include <qwidget.h>
-#include <kprocess.h>
+#include <QWidget>
 #include <KUrl>
 
 class FileListItem;
@@ -68,8 +67,6 @@ private:
 
     bool modeJustChanged;
 
-    KProcess kfm;
-
     Config *config;
     
 signals:
