@@ -22,10 +22,12 @@ public:
     QList<ConversionPipeTrunk> codecTable();
     BackendPlugin::FormatInfo formatInfo( const QString& codecName );
 //     QString getCodecFromFile( const KUrl& filename, const QString& mimeType = "application/octet-stream" );
-    bool isConfigSupported( ActionType action );
-    void showConfigDialog( ActionType action, const QString& format, QWidget *parent );
+
+    bool isConfigSupported( ActionType action, const QString& codecName );
+    void showConfigDialog( ActionType action, const QString& codecName, QWidget *parent );
     bool hasInfo();
-    void showInfo();
+    void showInfo( QWidget *parent );
+    
     QWidget *newCodecWidget();
 
     int convert( const KUrl& inputFile, const KUrl& outputFile, const QString& inputCodec, const QString& outputCodec, ConversionOptions *_conversionOptions, TagData *tags = 0, bool replayGain = false );
