@@ -21,11 +21,11 @@ public:
 
     QList<ConversionPipeTrunk> codecTable();
     BackendPlugin::FormatInfo formatInfo( const QString& codecName );
-    QString getCodecFromFile( const KUrl& filename, const QString& mimeType = "application/octet-stream" );
-    bool isConfigSupported( ActionType action );
+//     QString getCodecFromFile( const KUrl& filename, const QString& mimeType = "application/octet-stream" );
+    bool isConfigSupported( ActionType action, const QString& format );
     void showConfigDialog( ActionType action, const QString& format, QWidget *parent );
     bool hasInfo();
-    void showInfo();
+    void showInfo( QWidget *parent );
     QWidget *newCodecWidget();
 
     int convert( const KUrl& inputFile, const KUrl& outputFile, const QString& inputCodec, const QString& outputCodec, ConversionOptions *_conversionOptions, TagData *tags = 0, bool replayGain = false );
