@@ -25,10 +25,10 @@ public:
     QList<ReplayGainPipe> codecTable();
     BackendPlugin::FormatInfo formatInfo( const QString& codecName );
 //     bool canApply( const KUrl& filename );
-//     bool isConfigSupported( ActionType action );
-//     bool showConfigDialog( ActionType action, const QString& format, QWidget *parent );
+    bool isConfigSupported( ActionType action, const QString& codecName );
+    void showConfigDialog( ActionType action, const QString& codecName, QWidget *parent );
     bool hasInfo();
-    void showInfo();
+    void showInfo( QWidget *parent );
 
     int apply( const KUrl::List& fileList, ApplyMode mode = Add );
     float parseOutput( const QString& output );
